@@ -68,9 +68,9 @@ gnome_scan_processor_common_init (GnomeScanProcessorCommon *object)
 	gnome_scan_plugin_params_add (GNOME_SCAN_PLUGIN (object), pspec);
 	
 	pspec = gs_param_spec_boolean ("enhance", N_("Automatic color enhancement"),
-								   N_("Color enhancement produce better photos, "
-								   "but take more time to process and can be "
-								   "useless for text."),
+								   N_("Color enhancement produces better "
+									  "photos, but takes more time to process "
+									  "and can be useless for text."),
 								   GS_PARAM_GROUP_PROCESSING_COMMON,
 								   TRUE,
 								   G_PARAM_WRITABLE);
@@ -120,9 +120,10 @@ gnome_scan_processor_common_get_child_nodes (GnomeScanPlugin *plugin, GeglNode *
 									be nice to expose this through
 									profile : photo, text, quick,
 									manual, … */
-								 "iterations", 10,
-								 "gamma", 2.,
-								 "samples", 30,
+								 "radius", 300,
+								 "iterations", 15,
+								 "gamma", 2.2,
+								 "samples", 10,
 								 NULL);
 		node = g_list_append (node, op);
 	}
